Exception: A2A::ExtendedAgentCardNotConfiguredError
- Defined in:
- lib/a2a/errors.rb
Overview
The agent does not have an extended agent card configured when one is required for the requested operation.
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
- #error_data ⇒ Object
-
#initialize(message: "Extended agent card is not configured") ⇒ ExtendedAgentCardNotConfiguredError
constructor
A new instance of ExtendedAgentCardNotConfiguredError.
Methods inherited from Error
Constructor Details
#initialize(message: "Extended agent card is not configured") ⇒ ExtendedAgentCardNotConfiguredError
Returns a new instance of ExtendedAgentCardNotConfiguredError.
163 164 165 |
# File 'lib/a2a/errors.rb', line 163 def initialize(message: "Extended agent card is not configured") super(, code: -32007, http_status: 400) end |
Instance Method Details
#error_data ⇒ Object
167 168 169 170 171 172 173 |
# File 'lib/a2a/errors.rb', line 167 def error_data [{ "@type" => "type.googleapis.com/google.rpc.ErrorInfo", "reason" => "EXTENDED_AGENT_CARD_NOT_CONFIGURED", "domain" => "a2a-protocol.org", }] end |