Exception: A2A::UnsupportedOperationError
- Defined in:
- lib/a2a/errors.rb
Overview
The requested operation or a specific aspect of it is not supported by this server agent implementation.
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
- #error_data ⇒ Object
-
#initialize(message: "Unsupported operation") ⇒ UnsupportedOperationError
constructor
A new instance of UnsupportedOperationError.
Methods inherited from Error
Constructor Details
#initialize(message: "Unsupported operation") ⇒ UnsupportedOperationError
Returns a new instance of UnsupportedOperationError.
111 112 113 |
# File 'lib/a2a/errors.rb', line 111 def initialize(message: "Unsupported operation") super(, code: -32004, http_status: 400) end |
Instance Method Details
#error_data ⇒ Object
115 116 117 118 119 120 121 |
# File 'lib/a2a/errors.rb', line 115 def error_data [{ "@type" => "type.googleapis.com/google.rpc.ErrorInfo", "reason" => "UNSUPPORTED_OPERATION", "domain" => "a2a-protocol.org", }] end |